import electron, { contextBridge, ipcRenderer } from 'electron'
import { electronAPI } from '@electron-toolkit/preload'

// Custom APIs for renderer
const api = {}

// Use `contextBridge` APIs to expose Electron APIs to
// renderer only if context isolation is enabled, otherwise
// just add to the DOM global.
if (process.contextIsolated) {
  try {
    contextBridge.exposeInMainWorld('electron', electronAPI)
    contextBridge.exposeInMainWorld('api', api)
    contextBridge.exposeInMainWorld('baseConfig', {
      getBaseConfig: () => ipcRenderer.invoke('getBaseConfig')
    })
    contextBridge.exposeInMainWorld('client', {
      getLOLClientWindowInfo: () => ipcRenderer.invoke('getLOLClientWindowInfo')
    })
  } catch (error) {
    console.error(error)
  }
} else {
  window.electron = electronAPI
  window.api = api
  window.electronAPI = {
    getBaseConfig: () => ipcRenderer.invoke('getBaseConfig')
  }
  window.electronAPI = {
    getLOLClientWindowInfo: () => ipcRenderer.invoke('getLOLClientWindowInfo')
  }
}
